pub enum ButtonEvent {
Push,
Release,
}Expand description
Events which describe changes in state for a button.
Variants
Push
The button was pressed.
It moved from a Released to a Pushed state.
Release
The button stopped being pressed
It moved from a Pushed to a Released state.