pub enum Error {
String(String),
NotFoundError,
FilePathError(FilePathError),
RenameFilePathError(RenameFilePathError),
LoadMidiFileError,
AlreadyAttachedError,
DimensionsDoNotMatch,
PlayFileError,
}Expand description
The Error type for all errors in the craydate crate.
Variants
String(String)
A general error which is described by the contained string.
NotFoundError
Indicates a file or resource was not found.
FilePathError(FilePathError)
An error when trying to use a path, which comes with additional context.
RenameFilePathError(RenameFilePathError)
An error when trying to rename a file, which comes with additional context.
LoadMidiFileError
Attempting to load a MIDI file was unsuccessful.
AlreadyAttachedError
A SoundChannel or SoundSource was already attached and can not be attached again.
DimensionsDoNotMatch
Bitmap dimentions are required to match but they failed to.
PlayFileError
An error occured trying to read from a file to play it as audio.